@@ -49,6 +49,12 @@ rand_effects <- function(model){
 
 count_convergence_warnings <- function(convergences){ # "Yes" or "No"
   # Count the convergence warnings
+  if (length(setdiff(convergences, c("Yes","No"))) > 0){
+    stop(paste0(
+      "'convergences' can only contain 'Yes' and 'No'. Found: ",
+      paste0(setdiff(convergences, c("Yes", "No")), collapse = ", "), "."
+    ))
+  }
   conv_warns = as.integer(table(convergences)['No'])
   if (is.na(conv_warns)){
     conv_warns = 0
@@ -89,6 +95,7 @@ replace_argument_in_model_specifics_if_null <- function(var_name, model_specific
     model_specifics[[var_name]] = new_value
 
   }
+
   model_specifics
 }
 
@@ -109,8 +116,10 @@ nest_results <- function(results){
 nest_models <- function(models){
   # Make tidied models into a tibble
   iter_models <- tibble::as_tibble(models)
+  if ("p.value" %ni% colnames(iter_models)){
+    iter_models[["p.value"]] <- NA
+  }
   iter_models <- iter_models %>%
-    mutate(p.value = ifelse(exists('p.value', where = iter_models), .data$p.value, NA)) %>%
     tidyr::nest() %>%
     dplyr::rename(Coefficients = data)
 
@@ -215,10 +224,80 @@ skip_test_if_old_R_version <- function(min_R_version = "3.6"){
 # Partly contributed by R. Mark Sharp
 set_seed_for_R_compatibility <- function(seed = 1) {
   version <- check_R_version()
-  if (version[["minor"]] >= 6) {
+  if ((version[["major"]] == 3 && version[["minor"]] >= 6) || version[["major"]] > 3) {
     args <- list(seed, sample.kind = "Rounding")
   } else {
     args <- list(seed)
   }
   suppressWarnings(do.call(set.seed, args))
 }
+
+# Numeric Argument Checks
+
+is_wholenumber_ <- function(n) {
+
+  # If n is a whole number
+  # .. return TRUE
+  # else
+  # .. return FALSE
+
+  return( floor(n) == n )
+}
+
+arg_is_wholenumber_ <- function(n){
+
+  # Checks if n is a whole number of either
+  # type integer or numeric
+  # Returns TRUE if yes, else FALSE
+
+  # If n is an integer, return TRUE
+  # else check if it is a numeric
+  # .. if yes, check if it is a whole number
+  # .... if yes, return TRUE
+  # .... if no, return FALSE
+  # .. if not a numeric
+  # .... return FALSE
+
+  if ( is.integer(n) ){
+
+    return(TRUE)
+
+  } else if ( is.numeric(n) ){
+
+    if ( is_wholenumber_(n) ){
+
+      return(TRUE)
+
+    } else {
+
+      return(FALSE)
+    }
+
+  } else {
+
+    return(FALSE)
+  }
+}
+
+arg_is_number_ <- function(n){
+
+  # Checks if n is either an integer or a numeric
+  # Returns TRUE if yes, FALSE if no
+
+  if ( is.integer(n) || is.numeric(n) ){
+
+    return(TRUE)
+
+  } else {
+
+    return(FALSE)
+
+  }
+
+}
+is_between_ <- function(x, a, b) {
+
+  # Checks if x is between a and b
+
+  x > a & x < b
+}
